#  This file is part of TALER
#  (C) 2016 INRIA
#
#  TALER is free software; you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free Software
#  Foundation; either version 3, or (at your option) any later version.
#
#  TALER is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
#  A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License along with
#  TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
#
#  @author Marcello Stanisci

from django.conf import settings
from .errors import BadAmount
import re
import math
import logging

logger = logging.getLogger(__name__)

def floatify(amount_dict):
    return amount_dict['value'] + ( float(amount_dict['fraction']) / float(settings.FRACTION))

def stringify_amount(amount_float):
    o = "".join(["%.", "%sf" % settings.NDIGITS])
    return o % amount_float

# Return amount object from string like "x.yz CURRENCY".
# We don't take "x CURRENCY", if no fractional part is needed;
# use "x.00 CURRENCY" instead.

def parse_amount(amount_str):
    parsed = re.search('([0-9]+\.[0-9]+) ([A-Z]+)', amount_str)
    if not parsed:
        raise BadAmount(amount_str)
    amount = round(float(parsed.group(1)), settings.NDIGITS)
    amount_value = int(amount)

    if parsed.group(2) != settings.TALER_CURRENCY:
        raise CurrencyMismatchError()

    return {'value': amount_value,
            'fraction': int((amount - amount_value) * settings.FRACTION),
            'currency': parsed.group(2)}
